colour.quality.cri Module — Colour 0.3.0 documentation

# colour.quality.cri Module

## Colour Rendering Index

Defines colour rendering index computation objects:

- `colour_rendering_index()`

See also

Colour Rendering Index IPython Notebook

References

[1] | http://cie2.nist.gov/TC1-69/NIST%20CQS%20simulation%207.4.xls (Last accessed 10 June 2014)

`colour.quality.cri.` `TSC_COLORIMETRY_DATA_NXYZUVUVW`

  alias of `TscColorimetryData_nXYZuvUVW`

`colour.quality.cri.` `colour_rendering_index`(test_spd, additional_data=False)

  Returns the colour rendering index of given spectral power distribution.

  Parameters: | test_spd (SpectralPowerDistribution) – Test spectral power distribution. additional_data (bool, optional) – Output additional data.
  Returns: | Colour rendering index, Tsc data.
  Return type: | numeric or (numeric, dict)

  Examples

      >>> from colour import ILLUMINANTS_RELATIVE_SPDS
      >>> spd = ILLUMINANTS_RELATIVE_SPDS.get('F2')
      >>> colour_rendering_index(spd)
      64.1507331...